==> fet_6.7.6.orig.tar.bz2: fet-6.7.6/src/interface/helponstudentsminhoursdaily.cpp <==
/***************************************************************************
                          helponstudentsminhoursdaily.cpp  -  description
                             -------------------
    begin                : 2010
    copyright            : (C) 2010 by Lalescu Liviu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#include "helponstudentsminhoursdaily.h"

#include "longtextmessagebox.h"

#include "rules.h"
#include "timetable.h"

#include <QApplication>

extern Timetable gt;

void HelpOnStudentsMinHoursDaily::help(QWidget* parent)
{
	if(gt.rules.mode!=MORNINGS_AFTERNOONS){
		QString s=tr("Important information about constraints students (set) min hours daily:");
	
		s+="\n\n";
	
		s+=tr("Normally, these constraints do not allow empty days for students (and the check boxes in the dialogs are not selectable).");
		s+=" ";
		s+=tr("If you really need this constraint to allow empty days for students, you must enable the option from Settings->Advanced menu and select the check box.");
		s+="\n\n";
		s+=tr("Be very careful: if your school does not allow empty days for students or if a timetable does not exist with empty days for students, you MUST"
			" keep the constraints the usual way, without allowing empty days.");
		s+=" ";
		s+=tr("The reason is performance: speed of generation and the ability of FET to find a solution.");
		s+=" ";
		s+=tr("If you allow empty days to these constraints and a solution exists only with non-empty days, FET might not be able to find it.");
		s+="\n\n";
		s+=tr("For normal schools or high-schools, probably you won't need to enable this option. Maybe for universities you will need to enable this option.");
		s+="\n\n";
		s+=tr("So, remember: don't allow empty days unless you need it.");
	
		LongTextMessageBox::largeInformation(parent, tr("FET information"), s);
	}
	else{
		QString s=tr("Important information about constraints students (set) min hours daily:");
	
		s+="\n\n";
		
		s+=tr("You are working in the mornings-afternoons mode, in which the option to allow empty days should be available.");
		s+="\n\n";
		s+=tr("If you select not allowed empty days, it means not allowed empty real days. Empty days (half days,"
		 " FET days) are allowed. Each day (half day, FET day) will have either zero hours, or the minimum selected hours daily.");
	
		LongTextMessageBox::largeInformation(parent, tr("FET information"), s);
	}
}

==> fet_6.8.5.orig.tar.bz2: fet-6.8.5/src/interface/helponstudentsminhoursdaily.cpp <==
/***************************************************************************
                          helponstudentsminhoursdaily.cpp  -  description
                             -------------------
    begin                : 2010
    copyright            : (C) 2010 by Liviu Lalescu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#include "helponstudentsminhoursdaily.h"

#include "longtextmessagebox.h"

#include "rules.h"
#include "timetable.h"

#include <QApplication>

extern Timetable gt;

void HelpOnStudentsMinHoursDaily::help(QWidget* parent)
{
	if(gt.rules.mode!=MORNINGS_AFTERNOONS){
		QString s=tr("Important information about constraints students (set) min hours daily:");
	
		s+="\n\n";
	
		s+=tr("Normally, these constraints do not allow empty days for students (and the check boxes in the dialogs are not selectable).");
		s+=" ";
		s+=tr("If you really need this constraint to allow empty days for students, you must enable the option from Settings->Advanced menu and select the check box.");
		s+="\n\n";
		s+=tr("Be very careful: if your school does not allow empty days for students or if a timetable does not exist with empty days for students, you MUST"
			" keep the constraints the usual way, without allowing empty days.");
		s+=" ";
		s+=tr("The reason is performance: speed of generation and the ability of FET to find a solution.");
		s+=" ";
		s+=tr("If you allow empty days to these constraints and a solution exists only with non-empty days, FET might not be able to find it.");
		s+="\n\n";
		s+=tr("For normal schools or high-schools, probably you won't need to enable this option. Maybe for universities you will need to enable this option.");
		s+="\n\n";
		s+=tr("So, remember: don't allow empty days unless you need it.");
	
		LongTextMessageBox::largeInformation(parent, tr("FET information"), s);
	}
	else{
		QString s=tr("Important information about constraints students (set) min hours daily:");
	
		s+="\n\n";
		
		s+=tr("You are working in the mornings-afternoons mode, in which the option to allow empty days should be available.");
		s+="\n\n";
		s+=tr("If you select not allowed empty days, it means not allowed empty real days. Empty days (half days,"
		 " FET days) are allowed. Each day (half day, FET day) will have either zero hours, or the minimum selected hours daily.");
	
		LongTextMessageBox::largeInformation(parent, tr("FET information"), s);
	}
}
